﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows.Input;

using DevExpress.Xpf.Mvvm;

namespace TestProject
{
    /// <summary>
    /// 메인 뷰 모델
    /// </summary>
    public class MainViewModel : ViewModelBase
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Property
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region Show Document Window 명령 - ShowDocumentWindowCommand

        /// <summary>
        /// Show Document Window 명령
        /// </summary>
        public ICommand ShowDocumentWindowCommand { get; private set; }

        #endregion

        ////////////////////////////////////////////////////////////////////////////////////////// Private
        
        #region 문서 관리자 서비스 - DocumentManagerService

        /// <summary>
        /// 문서 관리자 서비스
        /// </summary>
        private IDocumentManagerService DocumentManagerService
        {
            get
            {
                return ServiceContainer.GetService<IDocumentManagerService>();
            }
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainViewModel()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainViewModel()
        {
            ShowDocumentWindowCommand = new DelegateCommand<string>(ShowDocumentWindowCommand_Execute);
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region Show Document Window 명령 실행시 처리하기 - ShowDocumentWindowCommand_Execute(documentName)

        /// <summary>
        /// Show Document Window 명령 실행시 처리하기
        /// </summary>
        /// <param name="documentName">문서명</param>
        private void ShowDocumentWindowCommand_Execute(string documentName)
        {
            IDocument document = DocumentManagerService.CreateDocument(documentName, null, this);

            document.Title          = documentName;
            document.DestroyOnClose = true;

            document.Show();
        }

        #endregion
    }
}